commit 5d940405e8fb7b9d33d4d7e7052c345ce43e6213
Author: Assos Assos <assos+forge@centrale-marseille.fr>
Date:   Wed Mar 25 23:12:27 2020 +0100

    Weekly update of contrib modules

diff --git a/drupal7/sites/all/modules/media/media.info b/drupal7/sites/all/modules/media/media.info
index 526af65e..542831b3 100644
--- a/drupal7/sites/all/modules/media/media.info
+++ b/drupal7/sites/all/modules/media/media.info
@@ -24,8 +24,8 @@ configure = admin/config/media/browser
 ; We have to add a fake version so Git checkouts do not fail Media dependencies
 version = 7.x-2.x-dev
 
-; Information added by Drupal.org packaging script on 2019-10-31
-version = "7.x-2.24"
+; Information added by Drupal.org packaging script on 2020-03-22
+version = "7.x-2.26"
 core = "7.x"
 project = "media"
-datestamp = "1572552486"
+datestamp = "1584902430"
diff --git a/drupal7/sites/all/modules/media/media.install b/drupal7/sites/all/modules/media/media.install
index 5ba3cf94..834c4977 100644
--- a/drupal7/sites/all/modules/media/media.install
+++ b/drupal7/sites/all/modules/media/media.install
@@ -112,9 +112,31 @@ function media_requirements($phase) {
 
   if ($phase == 'update') {
     $info = system_get_info('module', 'file_entity');
-    $file_entity_installed_date = $info['datestamp'];
     $file_entity_version = $info['version'];
     $file_entity_minimum_date = 1495439635;
+    if (isset($info['datestamp'])) {
+      $file_entity_installed_date = $info['datestamp'];
+    }
+    else {
+      if (strpos($file_entity_version, '7.x-3') !== FALSE) {
+        // Good version, any number that passes the condition is good.
+        $file_entity_installed_date = $file_entity_minimum_date + 1;
+      }
+      else {
+        // Check version 2 release and parse into a number.
+        // No need to check version 1 as that's checked below.
+        $version_number = str_replace('7.x-2.', '', $file_entity_version);
+        if (is_numeric($version_number)) {
+          // Plain number, so good version.
+          $file_entity_installed_date = $file_entity_minimum_date + 1;
+        }
+        else {
+          // Bad version or release (beta, alpha, unstable...).
+          $file_entity_installed_date = $file_entity_minimum_date - 1;
+        }
+      }
+    }
+
     // Time of 2017-05-22 07:53:55 is most recent commit in 7.x-2.0.
     if ($file_entity_installed_date < $file_entity_minimum_date) {
       $description = $t('Media 2.10 or newer requires <a href="@url">File entity 2.0 or newer (2.4 or higher recommended)</a>. Please download the correct version and make sure you have deleted the file_entity folder inside the media module directory.', array('@url' => 'http://drupal.org/project/file_entity'));
@@ -135,26 +157,6 @@ function media_requirements($phase) {
     }
   }
 
-  if (module_exists('entity_translation')) {
-    if ($phase == 'update' || $phase == 'install' || $phase == 'runtime' ) {
-      $entity_translation_info = system_get_info('module', 'entity_translation');
-      $et_installed_version = $entity_translation_info['version'];
-      $et_installed_datestamp = $entity_translation_info['datestamp'];
-      $march3rd_entity_translation_timestamp = 1488530885;
-      if (!isset($entity_translation_info['version']) || !isset($entity_translation_info['datestamp'])) {
-        $et_installed_datestamp = 1488530884;
-      }
-
-      if ($et_installed_datestamp < $march3rd_entity_translation_timestamp) {
-        $description = $t('Your entity_translation installation version: %version is too old. media requires entity_translation at least beta6 from march 3 2017 or newer.  Your choice is to either upgrade entity_translation or to disable it.', array('%version' => $et_installed_version));
-        $requirements['entity_translation']['description'] = $description;
-        $requirements['entity_translation']['severity'] = REQUIREMENT_ERROR;
-        $requirements['entity_translation']['value'] = $et_installed_version;
-        $requirements['entity_translation']['title'] = $t('Entity translation (when installed) with Media');
-        drupal_set_message($description, 'error', TRUE);
-      }
-    }
-  }
   return $requirements;
 }
 
diff --git a/drupal7/sites/all/modules/media/modules/media_bulk_upload/media_bulk_upload.info b/drupal7/sites/all/modules/media/modules/media_bulk_upload/media_bulk_upload.info
index 98767759..8ce4ff08 100644
--- a/drupal7/sites/all/modules/media/modules/media_bulk_upload/media_bulk_upload.info
+++ b/drupal7/sites/all/modules/media/modules/media_bulk_upload/media_bulk_upload.info
@@ -15,8 +15,8 @@ test_dependencies[] = plupload
 files[] = includes/MediaBrowserBulkUpload.inc
 files[] = tests/media_bulk_upload.test
 
-; Information added by Drupal.org packaging script on 2019-10-31
-version = "7.x-2.24"
+; Information added by Drupal.org packaging script on 2020-03-22
+version = "7.x-2.26"
 core = "7.x"
 project = "media"
-datestamp = "1572552486"
+datestamp = "1584902430"
diff --git a/drupal7/sites/all/modules/media/modules/media_internet/media_internet.info b/drupal7/sites/all/modules/media/modules/media_internet/media_internet.info
index 55ae9c82..d9444b06 100644
--- a/drupal7/sites/all/modules/media/modules/media_internet/media_internet.info
+++ b/drupal7/sites/all/modules/media/modules/media_internet/media_internet.info
@@ -12,8 +12,8 @@ files[] = includes/MediaInternetNoHandlerException.inc
 files[] = includes/MediaInternetValidationException.inc
 files[] = tests/media_internet.test
 
-; Information added by Drupal.org packaging script on 2019-10-31
-version = "7.x-2.24"
+; Information added by Drupal.org packaging script on 2020-03-22
+version = "7.x-2.26"
 core = "7.x"
 project = "media"
-datestamp = "1572552486"
+datestamp = "1584902430"
diff --git a/drupal7/sites/all/modules/media/modules/media_internet/tests/media_internet_test.info b/drupal7/sites/all/modules/media/modules/media_internet/tests/media_internet_test.info
index 9f09516c..0eae2c90 100644
--- a/drupal7/sites/all/modules/media/modules/media_internet/tests/media_internet_test.info
+++ b/drupal7/sites/all/modules/media/modules/media_internet/tests/media_internet_test.info
@@ -7,8 +7,8 @@ hidden = TRUE
 files[] = includes/MediaInternetTestStreamWrapper.inc
 files[] = includes/MediaInternetTestHandler.inc
 
-; Information added by Drupal.org packaging script on 2019-10-31
-version = "7.x-2.24"
+; Information added by Drupal.org packaging script on 2020-03-22
+version = "7.x-2.26"
 core = "7.x"
 project = "media"
-datestamp = "1572552486"
+datestamp = "1584902430"
diff --git a/drupal7/sites/all/modules/media/modules/media_migrate_file_types/media_migrate_file_types.info b/drupal7/sites/all/modules/media/modules/media_migrate_file_types/media_migrate_file_types.info
index 47231bd4..669b8288 100644
--- a/drupal7/sites/all/modules/media/modules/media_migrate_file_types/media_migrate_file_types.info
+++ b/drupal7/sites/all/modules/media/modules/media_migrate_file_types/media_migrate_file_types.info
@@ -8,8 +8,8 @@ dependencies[] = media
 
 configure = admin/structure/file-types/upgrade
 
-; Information added by Drupal.org packaging script on 2019-10-31
-version = "7.x-2.24"
+; Information added by Drupal.org packaging script on 2020-03-22
+version = "7.x-2.26"
 core = "7.x"
 project = "media"
-datestamp = "1572552486"
+datestamp = "1584902430"
diff --git a/drupal7/sites/all/modules/media/modules/media_wysiwyg/media_wysiwyg.info b/drupal7/sites/all/modules/media/modules/media_wysiwyg/media_wysiwyg.info
index bed509d0..c29b9e33 100644
--- a/drupal7/sites/all/modules/media/modules/media_wysiwyg/media_wysiwyg.info
+++ b/drupal7/sites/all/modules/media/modules/media_wysiwyg/media_wysiwyg.info
@@ -16,8 +16,8 @@ files[] = tests/media_wysiwyg.paragraph_fix_filter.test
 
 configure = admin/config/media/browser
 
-; Information added by Drupal.org packaging script on 2019-10-31
-version = "7.x-2.24"
+; Information added by Drupal.org packaging script on 2020-03-22
+version = "7.x-2.26"
 core = "7.x"
 project = "media"
-datestamp = "1572552486"
+datestamp = "1584902430"
diff --git a/drupal7/sites/all/modules/media/modules/media_wysiwyg_settings/media_wysiwyg_settings.features.filter.inc b/drupal7/sites/all/modules/media/modules/media_wysiwyg_settings/media_wysiwyg_settings.features.filter.inc
new file mode 100644
index 00000000..cdee6773
--- /dev/null
+++ b/drupal7/sites/all/modules/media/modules/media_wysiwyg_settings/media_wysiwyg_settings.features.filter.inc
@@ -0,0 +1,80 @@
+<?php
+
+/**
+ * @file
+ * media_wysiwyg_settings.features.filter.inc
+ */
+
+/**
+ * Implements hook_filter_default_formats().
+ */
+function media_wysiwyg_settings_filter_default_formats() {
+  $formats = array();
+
+  // Exported format: Filtered HTML.
+  $formats['filtered_html'] = array(
+    'format' => 'filtered_html',
+    'name' => 'Filtered HTML',
+    'cache' => 1,
+    'status' => 1,
+    'weight' => 0,
+    'filters' => array(
+      'media_filter_paragraph_fix' => array(
+        'weight' => -49,
+        'status' => 1,
+        'settings' => array(
+          'replace' => 1,
+        ),
+      ),
+      'filter_html' => array(
+        'weight' => -48,
+        'status' => 1,
+        'settings' => array(
+          'allowed_html' => '<a> <em> <strong> <cite> <blockquote> <code> <img> <h2> <h1> <h3> <div> <span> <section> <b> <ul> <ol> <li> <dl> <dt> <dd> <p> <table> <td> <tr>',
+          'filter_html_help' => 1,
+          'filter_html_nofollow' => 0,
+        ),
+      ),
+      'filter_htmlcorrector' => array(
+        'weight' => -42,
+        'status' => 1,
+        'settings' => array(),
+      ),
+      'media_filter' => array(
+        'weight' => -41,
+        'status' => 1,
+        'settings' => array(),
+      ),
+    ),
+  );
+
+  // Exported format: Full HTML.
+  $formats['full_html'] = array(
+    'format' => 'full_html',
+    'name' => 'Full HTML',
+    'cache' => 1,
+    'status' => 1,
+    'weight' => 1,
+    'filters' => array(
+      'filter_htmlcorrector' => array(
+        'weight' => -43,
+        'status' => 1,
+        'settings' => array(),
+      ),
+      'media_filter_paragraph_fix' => array(
+        'weight' => -42,
+        'status' => 1,
+        'settings' => array(
+          'replace' => 1,
+        ),
+      ),
+      'media_filter' => array(
+        'weight' => -41,
+        'status' => 1,
+        'settings' => array(),
+      ),
+    ),
+  );
+
+  return $formats;
+}
diff --git a/drupal7/sites/all/modules/media/modules/media_wysiwyg_settings/media_wysiwyg_settings.features.wysiwyg.inc b/drupal7/sites/all/modules/media/modules/media_wysiwyg_settings/media_wysiwyg_settings.features.wysiwyg.inc
new file mode 100644
index 00000000..9bf65520
--- /dev/null
+++ b/drupal7/sites/all/modules/media/modules/media_wysiwyg_settings/media_wysiwyg_settings.features.wysiwyg.inc
@@ -0,0 +1,232 @@
+<?php
+
+/**
+ * @file
+ * media_wysiwyg_settings.features.wysiwyg.inc
+ */
+
+/**
+ * Implements hook_wysiwyg_default_profiles().
+ */
+function media_wysiwyg_settings_wysiwyg_default_profiles() {
+  $profiles = array();
+
+  // Exported profile: filtered_html.
+  $profiles['filtered_html'] = array(
+    'format' => 'filtered_html',
+    'editor' => 'ckeditor',
+    'settings' => array(
+      'buttons' => array(
+        'default' => array(
+          'Bold' => 1,
+          'Italic' => 1,
+          'Underline' => 1,
+          'Strike' => 1,
+          'JustifyLeft' => 1,
+          'JustifyCenter' => 1,
+          'JustifyRight' => 1,
+          'JustifyBlock' => 1,
+          'BulletedList' => 1,
+          'NumberedList' => 1,
+          'Outdent' => 1,
+          'Indent' => 1,
+          'Undo' => 1,
+          'Link' => 1,
+          'Unlink' => 1,
+          'TextColor' => 1,
+          'BGColor' => 1,
+          'Superscript' => 1,
+          'Blockquote' => 1,
+          'Source' => 1,
+          'HorizontalRule' => 1,
+          'Cut' => 1,
+          'Copy' => 1,
+          'Paste' => 1,
+          'FontSize' => 1,
+          'Styles' => 1,
+          'Table' => 1,
+          'Find' => 1,
+          'Replace' => 1,
+          'CreateDiv' => 1,
+          'Maximize' => 1,
+        ),
+        'drupal' => array(
+          'media' => 1,
+        ),
+      ),
+      'theme' => 'advanced',
+      'language' => 'en',
+      'toolbarLocation' => 'top',
+      'resize_enabled' => 1,
+      'default_toolbar_grouping' => 0,
+      'simple_source_formatting' => 0,
+      'acf_mode' => 1,
+      'acf_allowed_content' => 'properties;
+table[class](*);
+tbody[class](*);
+tr[class](*);
+td[class,colspan](*);
+img[title,alt,src,data-cke-saved-src](wysiwyg-break,drupal-content);
+video[width,height,controls,src,controlslist,data-delta,data-fid,data-media-element](*);
+source[src,type,data-cke-saved-src];
+audio[controls,src](*);
+img[*](media-element,file-default,media-wysiwyg-align-right,media-wysiwyg-align-left,media-wysiwyg-align-center);
+p[class](*);
+audio[controls,src](*);
+b[class](*);
+p[class](default,fanc*,text-align*,Indent*);
+a[href,hreflang,data-entity-type,data-entity-uuid,title,target,class,tabindex](*);
+h1[class](*);
+h2[class](*);
+h3[class](*);
+h4[class](*);
+h5[class](*);
+h6[class](*);
+hr[class](*);
+div[class,aria-labelledby,data-parent,id](*);
+button[class,aria-controls,aria-expanded,data-target,data-toggle,type,id](*);
+sub[class](*);
+sup[class](*);
+strong[class](*);
+em[class](*);
+cite[class](*);
+footer[class](default);
+blockquote[class](*);
+ul[class,type](*);
+ol[class,start,type](*);
+span[!class](*);
+span[!lang](*);
+li[class](*);',
+      'css_setting' => 'theme',
+      'css_theme' => '',
+      'css_path' => '',
+      'stylesSet' => '',
+      'block_formats' => 'p,address,pre,h2,h3,h4,h5,h6,div',
+      'mobile_disable' => 0,
+      'forcePasteAsPlainText' => 0,
+      'pasteFromWordPromptCleanup' => 0,
+      'pasteFromWordRemoveFontStyles' => 0,
+    ),
+    'preferences' => array(
+      'default' => 1,
+      'user_choose' => 0,
+      'show_toggle' => 1,
+      'add_to_summaries' => 1,
+      'version' => '4.14.0.8a12b04171',
+    ),
+    'name' => 'formatfiltered_html',
+    'rdf_mapping' => array(),
+  );
+
+  // Exported profile: full_html.
+  $profiles['full_html'] = array(
+    'format' => 'full_html',
+    'editor' => 'ckeditor',
+    'settings' => array(
+      'buttons' => array(
+        'default' => array(
+          'Bold' => 1,
+          'Italic' => 1,
+          'Underline' => 1,
+          'Strike' => 1,
+          'JustifyLeft' => 1,
+          'JustifyCenter' => 1,
+          'BulletedList' => 1,
+          'NumberedList' => 1,
+          'Outdent' => 1,
+          'Indent' => 1,
+          'Undo' => 1,
+          'Redo' => 1,
+          'Link' => 1,
+          'Unlink' => 1,
+          'Anchor' => 1,
+          'Image' => 1,
+          'BGColor' => 1,
+          'Superscript' => 1,
+          'Subscript' => 1,
+          'Blockquote' => 1,
+          'Source' => 1,
+          'HorizontalRule' => 1,
+          'Cut' => 1,
+          'Copy' => 1,
+          'Paste' => 1,
+          'Font' => 1,
+          'FontSize' => 1,
+          'Styles' => 1,
+          'Table' => 1,
+          'Find' => 1,
+          'Replace' => 1,
+          'CreateDiv' => 1,
+          'Iframe' => 1,
+          'Maximize' => 1,
+        ),
+        'drupal' => array(
+          'media' => 1,
+        ),
+      ),
+      'theme' => 'advanced',
+      'language' => 'en',
+      'toolbarLocation' => 'top',
+      'resize_enabled' => 1,
+      'default_toolbar_grouping' => 0,
+      'simple_source_formatting' => 0,
+      'acf_mode' => 0,
+      'acf_allowed_content' => 'properties;
+table[class](*);
+tbody[class](*);
+tr[class](*);
+td[class,colspan](*);
+img[title,alt,src,data-cke-saved-src](wysiwyg-break,drupal-content);
+video[width,height,controls,src,controlslist,data-delta,data-fid,data-media-element](*);
+source[src,type,data-cke-saved-src];
+audio[controls,src](*);
+img[*](media-element,file-default,media-wysiwyg-align-right,media-wysiwyg-align-left,media-wysiwyg-align-center);
+p[class](*);
+audio[controls,src](*);
+b[class](*);
+p[class](default,fanc*,text-align*,Indent*);
+a[href,hreflang,data-entity-type,data-entity-uuid,title,target,class,tabindex](*);
+h1[class](*);
+h2[class](*);
+h3[class](*);
+h4[class](*);
+h5[class](*);
+h6[class](*);
+hr[class](*);
+div[class,aria-labelledby,data-parent,id](*);
+button[class,aria-controls,aria-expanded,data-target,data-toggle,type,id](*);
+sub[class](*);
+sup[class](*);
+strong[class](*);
+em[class](*);
+cite[class](*);
+footer[class](default);
+blockquote[class](*);
+ul[class,type](*);
+ol[class,start,type](*);
+span[!class](*);
+span[!lang](*);
+li[class](*);',
+      'css_setting' => 'theme',
+      'css_theme' => '',
+      'css_path' => '',
+      'stylesSet' => '',
+      'block_formats' => 'p,address,pre,h2,h3,h4,h5,h6,div',
+      'mobile_disable' => 0,
+      'forcePasteAsPlainText' => 0,
+      'pasteFromWordPromptCleanup' => 0,
+      'pasteFromWordRemoveFontStyles' => 0,
+    ),
+    'preferences' => array(
+      'default' => 1,
+      'user_choose' => 0,
+      'show_toggle' => 1,
+      'add_to_summaries' => 1,
+      'version' => '4.14.0.8a12b04171',
+    ),
+    'name' => 'formatfull_html',
+    'rdf_mapping' => array(),
+  );
+
+  return $profiles;
+}
diff --git a/drupal7/sites/all/modules/media/modules/media_wysiwyg_settings/media_wysiwyg_settings.info b/drupal7/sites/all/modules/media/modules/media_wysiwyg_settings/media_wysiwyg_settings.info
new file mode 100644
index 00000000..b99aa97d
--- /dev/null
+++ b/drupal7/sites/all/modules/media/modules/media_wysiwyg_settings/media_wysiwyg_settings.info
@@ -0,0 +1,20 @@
+name = Media Wysiwyg Settings
+description = If you are using the wysiwyg module with the ckeditor library and you want to embed media, enable this for working defaults
+core = 7.x
+package = User Interface
+version = 7.x-4.1
+dependencies[] = features
+dependencies[] = filter
+dependencies[] = media_wysiwyg
+dependencies[] = wysiwyg
+features[features_api][] = api:2
+features[filter][] = filtered_html
+features[filter][] = full_html
+features[wysiwyg][] = filtered_html
+features[wysiwyg][] = full_html
+
+; Information added by Drupal.org packaging script on 2020-03-22
+version = "7.x-2.26"
+core = "7.x"
+project = "media"
+datestamp = "1584902430"
diff --git a/drupal7/sites/all/modules/media/modules/media_wysiwyg_settings/media_wysiwyg_settings.module b/drupal7/sites/all/modules/media/modules/media_wysiwyg_settings/media_wysiwyg_settings.module
new file mode 100644
index 00000000..8ed882c5
--- /dev/null
+++ b/drupal7/sites/all/modules/media/modules/media_wysiwyg_settings/media_wysiwyg_settings.module
@@ -0,0 +1,6 @@
+<?php
+
+/**
+ * @file
+ * Drupal needs this blank file.
+ */
diff --git a/drupal7/sites/all/modules/media/modules/media_wysiwyg_view_mode/media_wysiwyg_view_mode.info b/drupal7/sites/all/modules/media/modules/media_wysiwyg_view_mode/media_wysiwyg_view_mode.info
index e42ee555..b62c2394 100644
--- a/drupal7/sites/all/modules/media/modules/media_wysiwyg_view_mode/media_wysiwyg_view_mode.info
+++ b/drupal7/sites/all/modules/media/modules/media_wysiwyg_view_mode/media_wysiwyg_view_mode.info
@@ -3,8 +3,8 @@ description = DEPRECATED, this folder is only here so that the module can be uni
 package = Media
 core = 7.x
 
-; Information added by Drupal.org packaging script on 2019-10-31
-version = "7.x-2.24"
+; Information added by Drupal.org packaging script on 2020-03-22
+version = "7.x-2.26"
 core = "7.x"
 project = "media"
-datestamp = "1572552486"
+datestamp = "1584902430"
diff --git a/drupal7/sites/all/modules/media/modules/mediafield/mediafield.info b/drupal7/sites/all/modules/media/modules/mediafield/mediafield.info
index efb220b1..9277efff 100644
--- a/drupal7/sites/all/modules/media/modules/mediafield/mediafield.info
+++ b/drupal7/sites/all/modules/media/modules/mediafield/mediafield.info
@@ -4,8 +4,8 @@ package = Media
 core = 7.x
 dependencies[] = media
 
-; Information added by Drupal.org packaging script on 2019-10-31
-version = "7.x-2.24"
+; Information added by Drupal.org packaging script on 2020-03-22
+version = "7.x-2.26"
 core = "7.x"
 project = "media"
-datestamp = "1572552486"
+datestamp = "1584902430"
diff --git a/drupal7/sites/all/modules/media/tests/media_module_test.info b/drupal7/sites/all/modules/media/tests/media_module_test.info
index 49ce4471..1230c41d 100644
--- a/drupal7/sites/all/modules/media/tests/media_module_test.info
+++ b/drupal7/sites/all/modules/media/tests/media_module_test.info
@@ -6,8 +6,8 @@ hidden = TRUE
 
 files[] = includes/MediaModuleTest.inc
 
-; Information added by Drupal.org packaging script on 2019-10-31
-version = "7.x-2.24"
+; Information added by Drupal.org packaging script on 2020-03-22
+version = "7.x-2.26"
 core = "7.x"
 project = "media"
-datestamp = "1572552486"
+datestamp = "1584902430"
diff --git a/drupal7/sites/all/modules/media_ckeditor/README.txt b/drupal7/sites/all/modules/media_ckeditor/README.txt
index 8dce5f6f..01d91084 100644
--- a/drupal7/sites/all/modules/media_ckeditor/README.txt
+++ b/drupal7/sites/all/modules/media_ckeditor/README.txt
@@ -43,6 +43,10 @@ CKEditor Library Plugins
 INSTALLATION
 ------------
 
+***Very NEW***
+  A module (sub module/feature) is provided with media_ckeditor , enable it and it will configure text format and working ckeditor defaults.
+  Refer to the section below for dependency installation and troubleshooting, you will need the ckeditor library 4.14.0 installed (minimum recommended).
+***Very NEW***
 ***NEW***
   For a quicker and easier setup, follow this recipe
   https://www.drupal.org/node/2843391
diff --git a/drupal7/sites/all/modules/media_ckeditor/media_ckeditor.info b/drupal7/sites/all/modules/media_ckeditor/media_ckeditor.info
index 30b64157..f9e1e493 100644
--- a/drupal7/sites/all/modules/media_ckeditor/media_ckeditor.info
+++ b/drupal7/sites/all/modules/media_ckeditor/media_ckeditor.info
@@ -15,8 +15,8 @@ test_dependencies[] = ckeditor
 test_dependencies[] = views
 test_dependencies[] = ctools
 
-; Information added by Drupal.org packaging script on 2019-07-11
-version = "7.x-2.10"
+; Information added by Drupal.org packaging script on 2020-03-22
+version = "7.x-2.14"
 core = "7.x"
 project = "media_ckeditor"
-datestamp = "1562859187"
+datestamp = "1584902065"
diff --git a/drupal7/sites/all/modules/media_ckeditor/media_ckeditor.module b/drupal7/sites/all/modules/media_ckeditor/media_ckeditor.module
index 6b13b029..5bbb2234 100644
--- a/drupal7/sites/all/modules/media_ckeditor/media_ckeditor.module
+++ b/drupal7/sites/all/modules/media_ckeditor/media_ckeditor.module
@@ -125,18 +125,15 @@ function media_ckeditor_pre_render_media($element) {
   else {
     $instance = FALSE;
   }
+  // Build JavaScript data to be attached to the element.
+  $data['media_ckeditor']['image_properties'] = variable_get('media_ckeditor_image_properties', FALSE);
   if (!empty($instance['settings']['wysiwyg_insert'])) {
-    $element['#attached']['js'][] = array(
-      'type' => 'setting',
-      'data' => array(
-        'media_ckeditor' => array(
-          'wysiwyg_insert' => array(
-            $element['#field_name'] => TRUE,
-          ),
-        ),
-      ),
-    );
+    $data['media_ckeditor']['wysiwyg_insert'][$element['#field_name']] = TRUE;
   }
+  $element['#attached']['js'][] = array(
+    'type' => 'setting',
+    'data' => $data,
+  );
   return $element;
 }
 
@@ -202,6 +199,12 @@ function media_ckeditor_form_media_admin_config_browser_alter(&$form, &$form_sta
     '#description' => t('Check this box to render files in the WYSIWYG dynamically, to reflect any field overrides the user may have specified. Note that this requires the user has the corresponding permission: "View overridden file entities in wysiwyg"'),
     '#default_value' => variable_get('media_ckeditor_fully_rendered_files', FALSE),
   );
+  $form['media_ckeditor']['media_ckeditor_image_properties'] = array(
+    '#type' => 'checkbox',
+    '#title' => t('Allow Image Properties configuration'),
+    '#description' => t('Check this box to allow images inserted with the Media module to be resized and edited using the Image Properties menu option. Otherwise, resizing options should be provided as different image view modes.'),
+    '#default_value' => variable_get('media_ckeditor_image_properties', FALSE),
+  );
 }
 
 /**
diff --git a/drupal7/sites/all/modules/media_ckeditor/modules/media_ckeditor_settings/media_ckeditor_settings.features.ckeditor_profile.inc b/drupal7/sites/all/modules/media_ckeditor/modules/media_ckeditor_settings/media_ckeditor_settings.features.ckeditor_profile.inc
new file mode 100644
index 00000000..dbcbec3e
--- /dev/null
+++ b/drupal7/sites/all/modules/media_ckeditor/modules/media_ckeditor_settings/media_ckeditor_settings.features.ckeditor_profile.inc
@@ -0,0 +1,280 @@
+<?php
+
+/**
+ * @file
+ * media_ckeditor_settings.features.ckeditor_profile.inc
+ */
+
+/**
+ * Implements hook_ckeditor_profile_defaults().
+ */
+function media_ckeditor_settings_ckeditor_profile_defaults() {
+  $data = array(
+    'Advanced' => array(
+      'name' => 'Advanced',
+      'settings' => array(
+        'ss' => 2,
+        'toolbar' => '[
+    [\'Source\'],
+    [\'Cut\',\'Copy\',\'Paste\',\'PasteText\',\'PasteFromWord\',\'-\',\'SpellChecker\', \'Scayt\'],
+    [\'Undo\',\'Redo\',\'Find\',\'Replace\',\'-\',\'SelectAll\'],
+    [\'Image\',\'Media\',\'Flash\',\'Table\',\'HorizontalRule\',\'Smiley\',\'SpecialChar\'],
+    [\'Maximize\', \'ShowBlocks\'],
+    \'/\',
+    [\'Format\'],
+    [\'Bold\',\'Italic\',\'Underline\',\'Strike\',\'-\',\'Subscript\',\'Superscript\',\'-\',\'RemoveFormat\'],
+    [\'NumberedList\',\'BulletedList\',\'-\',\'Outdent\',\'Indent\',\'Blockquote\'],
+    [\'JustifyLeft\',\'JustifyCenter\',\'JustifyRight\',\'JustifyBlock\',\'-\',\'BidiLtr\',\'BidiRtl\'],
+    [\'Link\',\'Unlink\',\'Anchor\',\'Linkit\']
+]
+    ',
+        'expand' => 't',
+        'default' => 't',
+        'show_toggle' => 't',
+        'uicolor' => 'custom',
+        'uicolor_user' => '#542002',
+        'width' => '100%',
+        'lang' => 'en',
+        'auto_lang' => 't',
+        'language_direction' => 'default',
+        'allowed_content' => 't',
+        'extraAllowedContent' => 'properties;
+table[class](*);
+tbody[class](*);
+tr[class](*);
+td[class,colspan](*);
+img[title,alt,src,data-cke-saved-src](wysiwyg-break,drupal-content);
+video[width,height,controls,src,controlslist,data-delta,data-fid,data-media-element](*);
+source[src,type,data-cke-saved-src];
+audio[controls,src](*);
+img[*](media-element,file-default,media-wysiwyg-align-right,media-wysiwyg-align-left,media-wysiwyg-align-center);
+p[class](*);
+audio[controls,src](*);
+b[class](*);
+p[class](default,fanc*,text-align*,Indent*);
+a[href,hreflang,data-entity-type,data-entity-uuid,title,target,class,tabindex](*);
+h1[class](*);
+h2[class](*);
+h3[class](*);
+h4[class](*);
+h5[class](*);
+h6[class](*);
+hr[class](*);
+div[class,aria-labelledby,data-parent,id](*);
+button[class,aria-controls,aria-expanded,data-target,data-toggle,type,id](*);
+sub[class](*);
+sup[class](*);
+strong[class](*);
+em[class](*);
+cite[class](*);
+footer[class](default);
+blockquote[class](*);
+ul[class,type](*);
+ol[class,start,type](*);
+span[!class](*);
+span[!lang](*);
+li[class](*);',
+        'enter_mode' => 'p',
+        'shift_enter_mode' => 'br',
+        'font_format' => 'p;div;pre;address;h1;h2;h3;h4;h5;h6',
+        'custom_formatting' => 'f',
+        'formatting' => array(
+          'custom_formatting_options' => array(
+            'indent' => 'indent',
+            'breakBeforeOpen' => 'breakBeforeOpen',
+            'breakAfterOpen' => 'breakAfterOpen',
+            'breakAfterClose' => 'breakAfterClose',
+            'breakBeforeClose' => 0,
+            'pre_indent' => 0,
+          ),
+        ),
+        'css_mode' => 'none',
+        'css_path' => '',
+        'css_style' => 'theme',
+        'styles_path' => '',
+        'filebrowser' => 'none',
+        'filebrowser_image' => '',
+        'filebrowser_flash' => '',
+        'UserFilesPath' => '%b%f/',
+        'UserFilesAbsolutePath' => '%d%b%f/',
+        'forcePasteAsPlainText' => 'f',
+        'html_entities' => 'f',
+        'scayt_autoStartup' => 'f',
+        'theme_config_js' => 'f',
+        'js_conf' => '',
+        'loadPlugins' => array(
+          'drupalbreaks' => array(
+            'name' => 'drupalbreaks',
+            'desc' => 'Plugin for inserting Drupal teaser and page breaks.',
+            'path' => '%plugin_dir%drupalbreaks/',
+            'buttons' => array(
+              'DrupalBreak' => array(
+                'label' => 'DrupalBreak',
+                'icon' => 'images/drupalbreak.png',
+              ),
+            ),
+            'default' => 't',
+          ),
+          'media' => array(
+            'name' => 'media',
+            'desc' => 'Plugin for embedding files using Media CKEditor',
+            'path' => '%base_path%profiles/media_dev/modules/contrib/media_ckeditor/js/plugins/media/',
+            'buttons' => array(
+              'Media' => array(
+                'icon' => 'icons/media.png',
+                'label' => 'Add media',
+              ),
+            ),
+            'default' => 'f',
+          ),
+        ),
+      ),
+      'input_formats' => array(
+        'filtered_html' => 'Filtered HTML',
+      ),
+    ),
+    'CKEditor Global Profile' => array(
+      'name' => 'CKEditor Global Profile',
+      'settings' => array(
+        'skin' => 'moono',
+        'ckeditor_path' => '//cdn.ckeditor.com/4.14.0/full-all',
+        'ckeditor_local_path' => '',
+        'ckeditor_plugins_path' => '%m/plugins',
+        'ckeditor_plugins_local_path' => '',
+        'ckfinder_path' => '%m/ckfinder',
+        'ckfinder_local_path' => '',
+        'ckeditor_aggregate' => 'f',
+        'toolbar_wizard' => 't',
+        'loadPlugins' => array(),
+      ),
+      'input_formats' => array(),
+    ),
+    'Full' => array(
+      'name' => 'Full',
+      'settings' => array(
+        'ss' => 2,
+        'toolbar' => '[
+    [\'Source\'],
+    [\'Cut\',\'Copy\',\'Paste\',\'PasteText\',\'PasteFromWord\',\'-\',\'SpellChecker\', \'Scayt\'],
+    [\'Undo\',\'Redo\',\'Find\',\'Replace\',\'-\',\'SelectAll\'],
+    [\'Image\',\'Media\',\'Flash\',\'Table\',\'HorizontalRule\',\'Smiley\',\'SpecialChar\',\'Iframe\'],
+    \'/\',
+    [\'Bold\',\'Italic\',\'Underline\',\'Strike\',\'-\',\'Subscript\',\'Superscript\',\'-\',\'RemoveFormat\'],
+    [\'NumberedList\',\'BulletedList\',\'-\',\'Outdent\',\'Indent\',\'Blockquote\',\'CreateDiv\'],
+    [\'JustifyLeft\',\'JustifyCenter\',\'JustifyRight\',\'JustifyBlock\',\'-\',\'BidiLtr\',\'BidiRtl\',\'-\',\'Language\'],
+    [\'Link\',\'Unlink\',\'Anchor\',\'Linkit\'],
+    [\'DrupalBreak\'],
+    \'/\',
+    [\'Format\',\'Font\',\'FontSize\'],
+    [\'TextColor\',\'BGColor\'],
+    [\'Maximize\', \'ShowBlocks\']
+]
+    ',
+        'expand' => 't',
+        'default' => 't',
+        'show_toggle' => 't',
+        'uicolor' => 'default',
+        'uicolor_user' => 'default',
+        'width' => '100%',
+        'lang' => 'en',
+        'auto_lang' => 't',
+        'language_direction' => 'default',
+        'allowed_content' => 'f',
+        'extraAllowedContent' => 'properties;
+table[class](*);
+tbody[class](*);
+tr[class](*);
+td[class,colspan](*);
+img[title,alt,src,data-cke-saved-src](wysiwyg-break,drupal-content);
+video[width,height,controls,src,controlslist,data-delta,data-fid,data-media-element](*);
+source[src,type,data-cke-saved-src];
+audio[controls,src](*);
+img[*](media-element,file-default,media-wysiwyg-align-right,media-wysiwyg-align-left,media-wysiwyg-align-center);
+p[class](*);
+audio[controls,src](*);
+b[class](*);
+p[class](default,fanc*,text-align*,Indent*);
+a[href,hreflang,data-entity-type,data-entity-uuid,title,target,class,tabindex](*);
+h1[class](*);
+h2[class](*);
+h3[class](*);
+h4[class](*);
+h5[class](*);
+h6[class](*);
+hr[class](*);
+div[class,aria-labelledby,data-parent,id](*);
+button[class,aria-controls,aria-expanded,data-target,data-toggle,type,id](*);
+sub[class](*);
+sup[class](*);
+strong[class](*);
+em[class](*);
+cite[class](*);
+footer[class](default);
+blockquote[class](*);
+ul[class,type](*);
+ol[class,start,type](*);
+span[!class](*);
+span[!lang](*);
+li[class](*);',
+        'enter_mode' => 'p',
+        'shift_enter_mode' => 'br',
+        'font_format' => 'p;div;pre;address;h1;h2;h3;h4;h5;h6',
+        'custom_formatting' => 'f',
+        'formatting' => array(
+          'custom_formatting_options' => array(
+            'indent' => 'indent',
+            'breakBeforeOpen' => 'breakBeforeOpen',
+            'breakAfterOpen' => 'breakAfterOpen',
+            'breakAfterClose' => 'breakAfterClose',
+            'breakBeforeClose' => 0,
+            'pre_indent' => 0,
+          ),
+        ),
+        'css_mode' => 'none',
+        'css_path' => '',
+        'css_style' => 'theme',
+        'styles_path' => '',
+        'filebrowser' => 'none',
+        'filebrowser_image' => '',
+        'filebrowser_flash' => '',
+        'UserFilesPath' => '%b%f/',
+        'UserFilesAbsolutePath' => '%d%b%f/',
+        'forcePasteAsPlainText' => 'f',
+        'html_entities' => 'f',
+        'scayt_autoStartup' => 'f',
+        'theme_config_js' => 'f',
+        'js_conf' => '',
+        'loadPlugins' => array(
+          'drupalbreaks' => array(
+            'name' => 'drupalbreaks',
+            'desc' => 'Plugin for inserting Drupal teaser and page breaks.',
+            'path' => '%plugin_dir%drupalbreaks/',
+            'buttons' => array(
+              'DrupalBreak' => array(
+                'label' => 'DrupalBreak',
+                'icon' => 'images/drupalbreak.png',
+              ),
+            ),
+            'default' => 't',
+          ),
+          'media' => array(
+            'name' => 'media',
+            'desc' => 'Plugin for embedding files using Media CKEditor',
+            'path' => '%base_path%profiles/media_dev/modules/contrib/media_ckeditor/js/plugins/media/',
+            'buttons' => array(
+              'Media' => array(
+                'icon' => 'icons/media.png',
+                'label' => 'Add media',
+              ),
+            ),
+            'default' => 'f',
+          ),
+        ),
+      ),
+      'input_formats' => array(
+        'full_html' => 'Full HTML',
+      ),
+    ),
+  );
+  return $data;
+}
diff --git a/drupal7/sites/all/modules/media_ckeditor/modules/media_ckeditor_settings/media_ckeditor_settings.features.filter.inc b/drupal7/sites/all/modules/media_ckeditor/modules/media_ckeditor_settings/media_ckeditor_settings.features.filter.inc
new file mode 100644
index 00000000..5ed05071
--- /dev/null
+++ b/drupal7/sites/all/modules/media_ckeditor/modules/media_ckeditor_settings/media_ckeditor_settings.features.filter.inc
@@ -0,0 +1,108 @@
+<?php
+
+/**
+ * @file
+ * media_ckeditor_settings.features.filter.inc
+ */
+
+/**
+ * Implements hook_filter_default_formats().
+ */
+function media_ckeditor_settings_filter_default_formats() {
+  $formats = array();
+
+  // Exported format: Filtered HTML.
+  $formats['filtered_html'] = array(
+    'format' => 'filtered_html',
+    'name' => 'Filtered HTML',
+    'cache' => 1,
+    'status' => 1,
+    'weight' => 0,
+    'filters' => array(
+      'media_filter_paragraph_fix' => array(
+        'weight' => -49,
+        'status' => 1,
+        'settings' => array(
+          'replace' => 1,
+        ),
+      ),
+      'filter_html' => array(
+        'weight' => -48,
+        'status' => 1,
+        'settings' => array(
+          'allowed_html' => '<a> <em> <strong> <cite> <blockquote> <code> <img> <h2> <h1> <h3> <div> <span> <section> <b> <ul> <ol> <li> <dl> <dt> <dd> <p> <table> <td> <tr>',
+          'filter_html_help' => 1,
+          'filter_html_nofollow' => 0,
+        ),
+      ),
+      'filter_htmlcorrector' => array(
+        'weight' => -42,
+        'status' => 1,
+        'settings' => array(),
+      ),
+      'media_filter' => array(
+        'weight' => -41,
+        'status' => 1,
+        'settings' => array(),
+      ),
+    ),
+  );
+
+  // Exported format: Full HTML.
+  $formats['full_html'] = array(
+    'format' => 'full_html',
+    'name' => 'Full HTML',
+    'cache' => 1,
+    'status' => 1,
+    'weight' => 1,
+    'filters' => array(
+      'filter_htmlcorrector' => array(
+        'weight' => -43,
+        'status' => 1,
+        'settings' => array(),
+      ),
+      'media_filter_paragraph_fix' => array(
+        'weight' => -42,
+        'status' => 1,
+        'settings' => array(
+          'replace' => 1,
+        ),
+      ),
+      'media_filter' => array(
+        'weight' => -41,
+        'status' => 1,
+        'settings' => array(),
+      ),
+    ),
+  );
+
+  // Exported format: Plain text.
+  $formats['plain_text'] = array(
+    'format' => 'plain_text',
+    'name' => 'Plain text',
+    'cache' => 1,
+    'status' => 1,
+    'weight' => 10,
+    'filters' => array(
+      'filter_html_escape' => array(
+        'weight' => 0,
+        'status' => 1,
+        'settings' => array(),
+      ),
+      'filter_url' => array(
+        'weight' => 1,
+        'status' => 1,
+        'settings' => array(
+          'filter_url_length' => 72,
+        ),
+      ),
+      'filter_autop' => array(
+        'weight' => 2,
+        'status' => 1,
+        'settings' => array(),
+      ),
+    ),
+  );
+
+  return $formats;
+}
diff --git a/drupal7/sites/all/modules/media_ckeditor/modules/media_ckeditor_settings/media_ckeditor_settings.info b/drupal7/sites/all/modules/media_ckeditor/modules/media_ckeditor_settings/media_ckeditor_settings.info
new file mode 100644
index 00000000..26c52224
--- /dev/null
+++ b/drupal7/sites/all/modules/media_ckeditor/modules/media_ckeditor_settings/media_ckeditor_settings.info
@@ -0,0 +1,23 @@
+name = Media Ckeditor Settings
+description = If you are using the media_ckeditor module and you want to embed media, enable this for working ACF defaults
+core = 7.x
+package = User interface
+version = 7.x-4.1
+dependencies[] = ckeditor
+dependencies[] = features
+dependencies[] = filter
+dependencies[] = media_ckeditor
+dependencies[] = media_wysiwyg
+features[ckeditor_profile][] = Advanced
+features[ckeditor_profile][] = CKEditor Global Profile
+features[ckeditor_profile][] = Full
+features[features_api][] = api:2
+features[filter][] = filtered_html
+features[filter][] = full_html
+features[filter][] = plain_text
+
+; Information added by Drupal.org packaging script on 2020-03-22
+version = "7.x-2.14"
+core = "7.x"
+project = "media_ckeditor"
+datestamp = "1584902065"
diff --git a/drupal7/sites/all/modules/media_ckeditor/modules/media_ckeditor_settings/media_ckeditor_settings.module b/drupal7/sites/all/modules/media_ckeditor/modules/media_ckeditor_settings/media_ckeditor_settings.module
new file mode 100644
index 00000000..8ed882c5
--- /dev/null
+++ b/drupal7/sites/all/modules/media_ckeditor/modules/media_ckeditor_settings/media_ckeditor_settings.module
@@ -0,0 +1,6 @@
+<?php
+
+/**
+ * @file
+ * Drupal needs this blank file.
+ */
diff --git a/drupal7/sites/all/modules/media_ckeditor/tests/media_ckeditor_test.info b/drupal7/sites/all/modules/media_ckeditor/tests/media_ckeditor_test.info
index 116dd093..1f5e9612 100644
--- a/drupal7/sites/all/modules/media_ckeditor/tests/media_ckeditor_test.info
+++ b/drupal7/sites/all/modules/media_ckeditor/tests/media_ckeditor_test.info
@@ -4,8 +4,8 @@ package = Media
 core = 7.x
 hidden = FALSE
 
-; Information added by Drupal.org packaging script on 2019-07-11
-version = "7.x-2.10"
+; Information added by Drupal.org packaging script on 2020-03-22
+version = "7.x-2.14"
 core = "7.x"
 project = "media_ckeditor"
-datestamp = "1562859187"
+datestamp = "1584902065"

diff --git a/drupal7/sites/all/modules/media_ckeditor/js/plugins/media/plugin.js b/drupal7/sites/all/modules/media_ckeditor/js/plugins/media/plugin.js
index 5622c5e2..0d57173d 100644
--- a/drupal7/sites/all/modules/media_ckeditor/js/plugins/media/plugin.js
+++ b/drupal7/sites/all/modules/media_ckeditor/js/plugins/media/plugin.js
@@ -19,8 +19,10 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
     mediaLegacyWrappers: false,
     hidpi: true,
     onLoad: function() {
-      // Check if this instance has widget support.
-      // mediaPluginDefinition.hasWidgetSupport = typeof(CKEDITOR.plugins.registered.widget) != 'undefined';
+      // Check if Image Properties option is set, and this instance has widget support.
+      if (!Drupal.settings.media_ckeditor.image_properties) {
+        mediaPluginDefinition.hasWidgetSupport = typeof(CKEDITOR.plugins.registered.widget) != 'undefined';
+      }
       // Add dependency to widget plugin if possible.
       if (Drupal.settings.ckeditor.plugins['media'].compareVersions(CKEDITOR.version, '4.3') >= 0 && mediaPluginDefinition.hasWidgetSupport) {
         mediaPluginDefinition.requires.push('widget');